{% extends "base.html" %}
{% block title %}Your challenges{% endblock %}
{% block content %}

{% with messages = get_flashed_messages(with_categories=true) %}

{% if messages %}

<div class="modal fade modal-warning" id="formerror" tabindex="-1" role="dialog" aria-labelledby="myModalLabel"
  aria-hidden="true">
  {% for category, message in messages %}
  <div class="modal-dialog">
    <div class="modal-content">
      <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span
            aria-hidden="true">&times;</span></button>
        <h4 class="modal-title" id="myModalLabel">{{ category }}</h4>
      </div>
      <div class="modal-body">
        <div class="modal-message">
          {{ message }}
        </div>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-warning" data-dismiss="modal">Close</button>
      </div>
    </div>
  </div>
  {% endfor %}
</div>
{% endif %}
{% endwith %}


<div class="col-xs-12 info-pages">
  <div class="card">
    <div class="card-header info-header">
      <div class="card-title">
        <div class="title">Your RAMP challenges</div>
      </div>
    </div>
    <div class="card-body">

      <p>
        RAMP challenges begin with an interesting supervised prediction
        problem for which there is data. Domain experts teaching
        clean and curate the data and formalize the problem, working
        with experienced data scientists if required. This process can
        take two weeks to six months, and results in a 'starting kit',
        which typically consists of:

        <ul>
          <li>
            A jupyter notebook that introduces the predictive
            problem, provides some background information, exploratory
            data analysis and data visualisation, explains the workflow
            and provides a simple example solution.
          </li>
          <li>
            A 'problem.py' file that parametrizes the setup and uses
            building blocks from <a href="https://github.com/paris-saclay-cds/ramp-workflow">
              RAMP workflow</a>.
          </li>
          <li>
            The data, split into training and test subsets.
          </li>
          <li>
            A requirements file detailing all the required software
            packages.
          </li>
        </ul>
      </p>
      <p>
        A challenge event can now be organised. These events may
        be part of a post-graduate level programme or a 'hackathon'.
        If the data science problem requires the mastering
        of a specific tool, the RAMP event can be preceded by a
        Training Sprint for explaining specific tools to the participants.
      </p>

      <p>
        RAMP data challenges has been used for teaching in many courses
        at various levels. Students usually love the platform for:
        <ul>
          <li>its competitive gaming aspect,</li>
          <li>being able to learn from each other in the open phase, and</li>
          <li>to compete as a group with other student groups on the same problem.</li>
        </ul>
      </p>

      <br>

      <p>
        <h2>Using RAMP for teaching</h2>
        If you are interested in using the platform for teaching,
        we can open a new event for any <a href="/problems">
          RAMP challenge</a>. You will have full control over the timeline
        of the event (start, moving from closed to open phase and end).
      </p>

      <p>
        At the end of your challenge we will give you a csv file with all
        the performance metrics of each student.
      </p>


      <br>

      <p>
        <h2>Creating a new RAMP challenge</h2>
        If you have a predictive problem you may be interested in
        developing a new RAMP challenge to incite data scientists to
        collaboratively prototype new models. All RAMP packages are
        open source and documented, allowing you to build your challenge using
        <a href="https://paris-saclay-cds.github.io/ramp-workflow/index.html">
          ramp-workflow</a> and run an event by setting up your own RAMP
        server using <a href="https://paris-saclay-cds.github.io/ramp-docs/stable/">
          ramp-board</a>.
      </p>

      <p>
        We may be able to work with you in developing your RAMP
        challenge or helping to organise events such as hackathons
        or use the problem in a classroom setting. We can also
        automatically benchmark the thousands of models that are already
        in the platform.
      </p>

      <br>

      <p>
        <h2>Contact us</h2>

        To use RAMP for teaching or to work with us to develop a new
        RAMP challenge or organise a new event, contact us at <a
          href="mailto:admin@ramp.studio"><strong>admin@ramp.studio</strong></a>.
      </p>


    </div>
  </div>
</div>


{% endblock %}
{% block scripts %}
<script>
  $(function () {
    $('#formerror').modal('toggle')
  });
</script>
{% endblock %}