<p>
    The RAMP software packages were developed by the <a
    href="http://www.datascience-paris-saclay.fr/">Paris-Saclay Center for Data
    Science (CDS)</a> to connect data science to domain sciences. The original
    aim was to enable efficient collaborative prototyping of machine
    learning workflows in order to solve the data analytics segment of
    high-impact science problems. We then realized that it is equally valuable
    for training novice data scientists, networking and obtaining data on the
    way data scientists work and collaborate with each other.
</p>
<p>
    The RAMP software has been used in many data challenge events aiming to
    solve predictive problems in science domains ranging from medicine to
    astrophysics. Data challenge events generally result in a model with
    significant predictive improvement over the baseline, which is very
    useful to domain scientists.
</p>
<br>
<p>
    <h2>RAMP usage</h2>
    <h3>Education</h3>
    <ul>
        <li>
            <a href="https://datascience-x-master-paris-saclay.fr/le-master/structure-des-enseignements/">
            Data Camp Masters 2 course</a> - part of the <a
            href="https://datascience-x-master-paris-saclay.fr/le-master/structure-des-enseignements/">
            Data Science Masters</a> at Institut Polytechnique de
            Paris (IPP) and <a href="https://www.universite-paris-saclay.fr/fr/formation/master/informatique#mention">
            Computer Science Masters</a> at Université Paris-Saclay.
        </li>
        <li>
            <a href="http://pierrechainais.ec-lille.fr/Centrale/Option_DAD/Accueil.html">
            Data Science and Artificial Intelligence Masters program </a> at
            Ecole Centrale de Lille.
        </li>
        <li>
            <a href="https://www.polytechnique.edu/bigdata/dssp/">
            Data Science Professional education programme</a> at Ecole
            Polytechnique.
        </li>
        <li>
            Machine Learning for Finance and Economics course at Université
            Panthéon-Assas.
        </li>
    </ul>

    <h3>RAMP challenge events</h3>
    <ul>
        <li>
            <a href="http://www.spipoll.org/">SPIPOLL project</a> - with the
            French National Museum of Natural History (read more at <a
            href="http://blog.heuritech.com/2015/10/27/first-on-insect-image-classification-at-paris-saclay-data-science-challenge/">
            this blog</a> by one of the participating start-ups).
        </li>
        <li>
            <a href="https://indico.lal.in2p3.fr/event/2888/">
            El Nino challenge</a> - ran at the fifth <a
            href="http://www2.cisl.ucar.edu/events/workshops/climate-informatics/2015/ci2015-hackathon">
            Climate Informatics</a> workshop in Boulder, Colorado.
        </li>
        <li>
            <a href="https://indico.lal.in2p3.fr/event/3095/">Macroeconomy
            Surrogate model challenge</a> - with
            <a href="http://www.parisschoolofeconomics.eu/en/">Paris School of
            Economics</a>.
        </li>
        <li>
            <a href="http://wiki.epidemium.cc/wiki/RAMP_:_Rapid_Analytics_and_Model_Prototyping">
            Cancer rate prediction</a> - with <a href="http://www.epidemium.cc/">
            Epidemium</a>.
        </li>
    </ul>

    <h3>Notable RAMP challenges</h3>
    <ul>
        <li>
            <a href="https://github.com/ramp-kits/variable_stars">Variable star classification</a>
        </li>
        <li>
            <a href="https://github.com/ramp-kits/el_nino">
            El Nino temperature prediction</a>
        </li>
        <li>
            <a href="https://github.com/ramp-kits/autism">
            Autism Spectrum Disorder detection</a>
            (<a href="https://paris-saclay-cds.github.io/autism_challenge/">Public event</a>)
        </li>
        <li>
            <a href="https://github.com/ramp-kits/pollenating_insects_3">
            Pollinating insect classification</a>
        </li>
    </ul>
    <p>A complete list of existing RAMP challenges can be found on the
        <a href="https://github.com/ramp-kits">
            RAMP starting kits</a> Github repository.
    </p>
</p>

<br>
<h2 class="ui horizontal header divider" id="contributors">Contributors</h2>

<div class="row">
    <div class="col-md-12">
        <div class="col-sm-4">
            <ul>
                <li><a href="https://www.linkedin.com/in/aboucaud/" target="_blank">Alexandre Boucaud</a></li>
                <li><a href="http://alexandre.gramfort.net" target="_blank">Alexandre Gramfort</a></li>
                <li><a href="http://www.mines-paristech.fr/Services/Annuaire/akin-kazakci" target="_blank">Akin Kazakçi</a></li>
                <li><a href="https://www.linkedin.com/in/balazskegl" target="_blank">Balázs Kégl</a></li>
            </ul>
        </div>
        <div class="col-sm-4">
            <ul>
                <li><a href="https://www.linkedin.com/in/camille-marini-b585b210/?originalSubdomain=fr" target="_blank">Camille Marini</a></li>
                <li><a href="https://www.linkedin.com/in/djalelbbz/" target="_blank">Djalel Benbouzid</a></li>
                <li><a href="https://glemaitre.github.io/" target="_blank">Guillaume Lemaitre</a></li>
                <li><a href="https://jorisvandenbossche.github.io/" target="_blank">Joris Van Den Bossche</a></li>
            </ul>
        </div>
        <div class="col-sm-4">
            <ul>
                <li><a href="https://github.com/lucyleeow" target="_blank">Lucy Liu</a></li>
                <li><a href="https://www.linkedin.com/in/mehdi-cherti-38424b20" target="_blank">Mehdi Cherti</a></li>
                <li><a href="http://maria.telenczuk.pl/" target="_blank">Maria Teleńczuk</a></li>
                <li><a href="https://www.linkedin.com/in/yohann-sitruk-47289133" target="_blank">Yohann Sitruk</a></li>
            </ul>
        </div>
    </div>
</div>

<br>
<h2 class="ui horizontal header divider" id="contact">Contact</h2>

The CDS is able to host a limited number of events, challenges, or course projects, organized outside the CDS. <a href="mailto:admin@ramp.studio">Contact us</a> if you are interested.
