{% extends "base.html" %}
{% block title %}History{% endblock %}
{% block content %}

<div class="col-xs-12 info-pages">
    <div class="card">
        <div class="card-header info-header">
            <div class="card-title">
                <div class="title">RAMP history</div>
            </div>
        </div>
        <div class="card-body">
            {% include 'description.html' %}
        </div>
    </div>
</div>
{% endblock %}
