{% extends "base.html" %}
{% block head %}
    {{ super() }}
    <link
        href="https://cdn.pydata.org/bokeh/release/bokeh-1.4.0.min.css"
        rel="stylesheet" type="text/css">
    <link
        href="https://cdn.pydata.org/bokeh/release/bokeh-widgets-1.4.0.min.css"
        rel="stylesheet" type="text/css">

    <script src="https://cdn.pydata.org/bokeh/release/bokeh-1.4.0.min.js"></script>
    <script src="https://cdn.pydata.org/bokeh/release/bokeh-widgets-1.4.0.min.js"></script>
{% endblock %}
{% block title %}{{ event.name }} Plots{% endblock %}
{% block content %}

<div class="page-title">
    <span class="title">{{ event.problem.title }}, {{ event.title }}</span>
</div>
<div class="col-xs-12">
  <div class="card">
    <div class="card-header">
      <div class="card-title">
          <div class="title">Plots</div>
      </div>
    </div>
  </div>
</div>

<div class="col-xs-12">
  <div class="card">
    {{ div|safe }}
    {{ script|safe }}
  </div>
</div>
{% endblock %}

