<!DOCTYPE html>
<html>

<head>
    <title>RAMP: collaborative data science challenges</title>
    <meta name="description" content="Collaborative crowdsourcing data challenge site for building and optimizing data science workflows for scientific and business applications.">
    <meta name="keyword" content="data science, data challenge, crowdsourcing, open innovation, Paris-Saclay, Center for Data Science, teaching data science, deep learning, time series, missing data, feature extraction, hyperopt, AutoML">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- Fonts -->
    <link href='https://fonts.googleapis.com/css?family=Roboto+Condensed:300,400' rel='stylesheet' type='text/css'>
    <link href='https://fonts.googleapis.com/css?family=Lato:300,400,700,900' rel='stylesheet' type='text/css'>
    <!-- CSS Libs -->
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/bootstrap.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/font-awesome.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/animate.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/bootstrap-switch.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/checkbox3.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/jquery.dataTables.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/dataTables.bootstrap.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/select2.min.css') }}">
    <!-- CSS App -->
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/style.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/themes/flat-blue.css') }}">
</head>

<body class="flat-blue landing-page">

    <div class="container">
        <nav class="navbar navbar-inverse navbar-fixed-top navbar-affix" data-spy="affix" data-offset-top="60">
          <div class="container">
            <div class="navbar-header">
              <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navbar" aria-expanded="false" aria-controls="navbar">
                <span class="sr-only">Toggle navigation</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
              </button>
              <a class="navbar-brand" href="#features"><img src="{{ url_for('static', filename='img/logo_CDS.svg') }}" height="26px"></a>
            </div>
            <div id="navbar" class="navbar-collapse collapse">
              <ul class="nav navbar-nav navbar-font-index">
                <li><a href="/problems">Our challenges</a></li>
                <li><a href="/teaching">Your challenges</a></li>
              </ul>
              <ul class="nav navbar-nav navbar-right navbar-font-index">
                <li><a href="/sign_up"><span class="glyphicon glyphicon-user"></span> Sign Up</a></li>
                <li><a href="/login"><span class="glyphicon glyphicon-log-in"></span> Login</a></li>
              </ul>
            </div>
          </div>
        </nav>
      </div>

    <div class="jumbotron app-header" id='titleback'>
        <div class="container header-title">
            <h2 class="text-center">
                <br>
                <div class="color-white"><span><img src="{{ url_for('static', filename='img/logo_CDS.svg') }}" alt="CDS logo" class="app-logo color-white" height="96px" style="max-width: 12%">&nbsp;RAMP</span></div>
            </h2>
            <p class="text-center color-white app-description">Rapid Analytics & Model Prototyping</p>
            <p class="text-center color-white app-description">using Python</p>
            <div class="header-button">
              <a class="btn btn-primary btn-lg app-btn" href="#features" role="button">Learn More »</a>
          </div>
          </div>
        </div>
    </div>

    <div class="container-fluid app-content-a" id="features">
        <div class="container">

                <div class="row">
                        <div class="col-md-12">
                            <h2 class="text-center app-content-header">RAMP data challenges</h2>
                            <p class="text-center app-content-description">
                            RAMP data challenges are a great way to collaboratively prototype and benchmark machine learning workflows. Participants submit their predictive solution (code), competing for the best score, and provide organisers with fully-functioning prototypes.
                            </p>
                        </div>
                    </div>

            <div class="row text-center app-content-details">
                <div class="col-md-4 col-sm-4">
                    <span class="fa-stack fa-lg fa-5x">
                      <i class="fa fa-circle-thin fa-stack-2x"></i>
                      <i class="fa fa-users fa-stack-1x"></i>
                    </span>
                    <h2>Collaborate</h2>
                    <p class="index-body">Solutions submitted by participants are made publically available during the 'open phase', at the end of a challenge. Participants can reuse and learn from each other's solutions, accelerating development.</p>
                </div>
                <div class="col-md-4 col-sm-4">
                    <span class="fa-stack fa-lg fa-5x">
                      <i class="fa fa-circle-thin fa-stack-2x"></i>
                      <i class="fa fa-cog fa-stack-1x"></i>
                    </span>
                    <h2>Prototype</h2>
                    <p class="index-body">RAMP workflow allows 'model blending'. A blend of the best models often achieves a better score than the best single submission.</p>
                </div>
                <div class="col-md-4 col-sm-4">
                    <span class="fa-stack fa-lg fa-5x">
                      <i class="fa fa-circle-thin fa-stack-2x"></i>
                      <i class="fa fa-graduation-cap fa-stack-1x"></i>
                    </span>
                    <h2>Learn</h2>
                    <p class="index-body">RAMP data challenges are a great tool to learn data science! Participants can learn from each other, especially during the 'open phase'.</p>
                </div>
            </div>
        </div>
    </div>

    <hr align="center" width="50%">

    <div class="container-fluid app-content-a" id="packages">
            <div class="container">

                <div class="row">
                    <div class="col-md-12">
                        <h2 class="text-center app-content-header">RAMP packages</h2>
                        <p class="text-center app-content-description">
                        RAMP packages offer versatile tools to define, build and optimize machine learning workflows via data challenges, great for prototyping models in your data science team.
                        </p>
                    </div>
                </div>

                <div class="row text-center">

                    <div class="col-md-6 col-sm-6">
                        <span class="fa-stack fa-lg fa-5x">
                          <i class="fa fa-circle-thin fa-stack-2x"></i>
                          <i class="fa fa-gears fa-stack-1x"></i>
                        </span>
                        <h2>RAMP workflow</h2>
                        <p class="index-body"><a href="https://github.com/paris-saclay-cds/ramp-workflow">RAMP workflow</a> allows you to formalise a machine learning workflow by defining score types (metrics), workflow elements and prediction types.</p>
                    </div>
                    <div class="col-md-6 col-sm-6">
                        <span class="fa-stack fa-lg fa-5x">
                          <i class="fa fa-circle-thin fa-stack-2x"></i>
                          <i class="fa fa-server fa-stack-1x"></i>
                        </span>
                        <h2>RAMP board</h2>
                        <p class="index-body"><a href="https://github.com/paris-saclay-cds/ramp-board">RAMP board</a> consists of a bundle of modules that allow you to easily setup your own RAMP server and deploy new data challenges.</p>
                    </div>
                </div>
            </div>
        </div>

    <hr align="center" width="50%">

    <div class="container-fluid app-content-a" id="about">
        <div class="container">
            <div class="row">
                <div class="col-md-12">
                    <h2 class="text-center app-content-header">RAMP in action</h2>
                    <br>
                </div>
            </div>
            <div class="row text-center">

                <div class="col-md-6 col-sm-6">
                    <span>
                        <iframe width="540" height="339" style="max-height: 10%; max-width: 90%"
                            src="https://www.youtube.com/embed/vQoH68hb85Q" frameborder="0" allowfullscreen></iframe>
                    </span>
                </div>
                <div class="col-md-6 col-sm-6">
                    <p class="index-body">
                    RAMP was originally developed as a tool for data scientists to efficiently and collaboratively solve the data analytics aspect of high-impact domain science problems. Since then, RAMP has undergone many iterations and has been used in teaching and benchmarking machine learning algorithms as well.
                    </p>
                    <br>
                    <span class="text-center"><a class="btn btn-hist" href="/description#history" role="button"> Project history » </a></span>
                    <br>
                    <span class="text-center"><a class="btn btn-hist-pad" href="mailto:admin@ramp.studio" role="button"> Contact us » </a></span>
                </div>
            </div>
        </div>
    </div>

    <br>

    <hr align="center" width="50%">

    <div class="container-fluid app-content-a" id="dev">
        <div class="container">
            <div class="row">
                <h2 class="text-center app-content-header">Developed by:</h2>
                <br>
                <div class="col-md-12">
                    <center>
                    <a href="https://www.datascience-paris-saclay.fr/" target="_blank">
                    <img src="{{url_for('static', filename='img/partners/upsaclay.png') }}" class="img" alt="Université Paris-Saclay" width="700vh" style="max-width: 95%;">
                    </a>
                    </center>
                </div>
            </div>
        </div>
    </div>

    <div class="container-fluid app-content-a" id="powered">
            <div class="container">
                <div class="row">
                    <div class="col-md-12">
                        {% if images|length > 0 %}
                        <h2 class="text-center app-content-header">Powered by:</h2>
                        <br>
                            {% for image in images %}
                            <center>
                                <!-- <a href="https://www.ovhcloud.com/en/" target="_blank"> -->
                                <img src="{{ url_for('static', filename='../static/img/powered_by/' + image) }}" class="img" alt='' height="80vh" style="max-width: 90%;">
                                <!-- </a> -->
                            </center>
                            {% endfor %}
                        {% endif %}
                    </div>
                </div>
            </div>
        </div>


    <!-- /END THE FEATURETTES -->
    <!-- FOOTER -->
    <footer class="app-footer">
      <div class="container">
          <center><span class="pull-left"><i class="icon fa fa-copyright"></i> RAMP version {{ version }} <a href="#"><i class="icon fa fa-long-arrow-up"></i><i class="icon fa fa-long-arrow-up"></i></a></span> &nbsp; &nbsp; &nbsp; &nbsp;
          <span><a href="/"><img src="{{ url_for('static', filename='img/logo_CDS_footer.svg') }}" height="20px"></a></span> &nbsp; &nbsp; &nbsp; &nbsp; <span><a href="mailto:admin@ramp.studio">Contact Us <i class="icon fa fa-envelope"></i></a></span>
          <span class="pull-right">Thanks to <a href="https://github.com/tui2tone/flat-admin-bootstrap-templates" target="_blank">tui2tone</a> for the  template!</span>
          </center>
      </div>
    </footer>
    <!-- Javascript Libs -->
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/jquery.min.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/bootstrap.min.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/Chart.min.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/bootstrap-switch.min.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/jquery.matchHeight-min.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/jquery.dataTables.min.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/dataTables.bootstrap.min.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/select2.full.min.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/ace/ace.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/ace/mode-html.js') }}"></script>
    <script type="text/javascript" src="{{ url_for('static', filename='lib/js/ace/theme-github.js') }}"></script>
    <!-- /.container -->
</body>

</html>
